<?php
/**
 * Email template for coupon for refund to admin
 *
 * @package woocommerce-smart-refunder/templates/
 * @version 1.4.3
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

global $smart_refunder;

if ( ! $order instanceof WC_Order ) {
	return;
}

wc_get_template( 'emails/email-header.php', array( 'email_heading' => wp_strip_all_tags( $email_heading ) ) );

$order_id = ( is_callable( array( $order, 'get_id' ) ) ) ? $order->get_id() : 0;

do_action( 'before_message_email_admin_coupon_for_refund', $order );

$refund_data = $order->get_meta( 'smart_refunder_two_step_refund_params', true );

$refund_amount_text = ( ! empty( $refund_data['refund_type'] ) && 'partial' === $refund_data['refund_type'] ) ? wc_price( $refund_data['amount'] ) : wc_price( $order->get_total() );
// Not escaping because it might contain HTML.
// phpcs:disable
$refund_text = ( ! empty( $refund_data['refund_mode'] ) && 'money' === $refund_data['refund_mode'] ) ? sprintf( __( 'refund of %s', 'woocommerce-smart-refunder' ), $refund_amount_text ) : sprintf( __( 'coupon of %s', 'woocommerce-smart-refunder' ), $refund_amount_text ); // phpcs:ignore

echo '<p>' . sprintf(
	__( 'Issued coupon against customer\'s refund request for order #%1$s. The request was for %2$s %3$s.', 'woocommerce-smart-refunder' ),
	$order->get_order_number(),
	$refund_text,
	( ! empty( $refund_data['reason'] ) ) ? __( 'because ', 'woocommerce-smart-refunder' ) . str_replace( '\\', '', $refund_data['reason'] ) : ''
) . '</p>';
// phpcs:enable
do_action( 'before_order_details_email_admin_coupon_for_refund', $order );

echo '<p>' . esc_html__( 'For your reference, order details are shown below.', 'woocommerce-smart-refunder' ) . '</p>';

?>

<?php /* translators: The order number */ ?>
<h3><?php printf( esc_html__( 'Order: %s', 'woocommerce-smart-refunder' ), esc_html( $order->get_order_number() ) ); ?></h3>

<?php do_action( 'before_order_item_table_email_admin_coupon_for_refund', $order ); ?>

<table cellspacing="0" cellpadding="6" style="width: 100%; border: 1px solid #eee;" border="1" bordercolor="#eee">
	<thead>
		<tr>
			<th scope="col" style="text-align:left; border: 1px solid #eee;"><?php echo esc_html__( 'Product', 'woocommerce-smart-refunder' ); ?></th>
			<th scope="col" style="text-align:left; border: 1px solid #eee;"><?php echo esc_html__( 'Quantity', 'woocommerce-smart-refunder' ); ?></th>
			<th scope="col" style="text-align:left; border: 1px solid #eee;"><?php echo esc_html__( 'Price', 'woocommerce-smart-refunder' ); ?></th>
		</tr>
	</thead>
	<tbody>
		<?php
		// Not escaping because it might contain HTML.
		echo wc_get_email_order_items( $order, array( 'show_sku' => true ) ); // phpcs:ignore
		?>
	</tbody>
	<tfoot>
		<?php
		$totals = $order->get_order_item_totals(); // phpcs:ignore
		if ( ! empty( $totals ) ) {
			$i = 0;
			// Not escaping because rows to display order total might contain HTML.
			// phpcs:disable
			foreach ( $totals as $total ) {
				$i++;
				?>
					<tr>
						<th scope="row" colspan="2" style="text-align:left; border: 1px solid #eee; 
						<?php
						if ( 1 === $i ) {
							echo esc_attr( 'border-top-width: 4px;' );
						}
						?>
						"><?php echo $total['label']; ?></th>
						<td style="text-align:left; border: 1px solid #eee; 
						<?php
						if ( 1 === $i ) {
							echo esc_attr( 'border-top-width: 4px;' );
						}
						?>
						"><?php echo $total['value']; ?></td>
					</tr>
					<?php
			}
			// phpcs:enable
		}
		?>
	</tfoot>
</table>

<div style="clear:both;"></div>

<?php do_action( 'after_order_item_table_email_admin_coupon_for_refund', $order ); ?>

<?php

wc_get_template( 'emails/email-footer.php' );
